const fs = require('fs');
const path = require('path');
const xml = require('xml');
const nuget = require('nuget-in-path');
const pkg = require(path.resolve(process.cwd(), './package.json'));

const nuspecPath = path.resolve(process.cwd(), './package.nuspec');

// Use these patterns to match all the files that should get included
// and generate a list of XML `file`
const files = glob.sync('dist/*')
  .map(
    file =>
      fs.statSync(path.resolve(process.cwd(),  file)).isFile() && {
        file: {
          _attr: {
            src: file,
          },
        },
      }
  )
  .filter(f => f);

// Generate nuspec file
const nuspec = xml(
  [
    {
      package: [
        {
          _attr: {
            xmlns: 'http://schemas.microsoft.com/packaging/2011/08/nuspec.xsd',
          },
        },
        {
          metadata: [
            { id: pkg.name },
            { version: pkg.version },
            { description: pkg.description },
            { authors: 'FezVrasta' },
            { projectUrl: pkg.homepage },
          ],
        },
        { files },
      ],
    },
  ],
  { declaration: true, indent: true }
);

fs.writeFileSync(nuspecPath, nuspec);

nuget.pack(nuspecPath, (err, nupkg) => {
  if (err) {
    return console.error(err);
  }
  nuget.push(nupkg, err => {
    if (err) {
      return console.error(err);
    }
    console.info(`Nuget: Successfully pushed ${nupkg.path}`);
  });
});
